==> xoops-2.4.5.tbz: www/xoops/htdocs/language/english/comment.php <==
<?php
/*
 You may not change or alter any portion of this comment or credits
 of supporting developers from this source code or any supporting source code
 which is considered copyrighted (c) material of the original comment or credit authors.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/**
 *  Xoops Language
 *
 * @copyright       The XOOPS Project http://sourceforge.net/projects/xoops/
 * @license         http://www.fsf.org/copyleft/gpl.html GNU public license
 * @package         kernel
 * @subpackage      Xoops Comment Language
 * @since           2.0.0
 * @author          Kazumi Ono <onokazu@xoops.org>
 * @version         $Id: comment.php 3751 2009-10-17 15:21:00Z trabis $
 */
defined('XOOPS_ROOT_PATH') or die('Restricted access');

// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team
define('_CM_TITLE', 'Title');
define('_CM_MESSAGE', 'Message');
define('_CM_DOSMILEY', 'Enable Smiley Icons');
define('_CM_DOHTML', 'Enable HTML Tags');
define('_CM_DOAUTOWRAP', 'Auto wrap lines');
define('_CM_DOXCODE', 'Enable XOOPS Codes');
define('_CM_REFRESH', 'Refresh');
define('_CM_PENDING', 'Pending');
define('_CM_HIDDEN', 'Hidden');
define('_CM_ACTIVE', 'Active');
define('_CM_STATUS', 'Status');
define('_CM_POSTCOMMENT', 'Post Comment');
define('_CM_REPLIES', 'Replies');
define('_CM_PARENT', 'Parent');
define('_CM_TOP', 'Top');
define('_CM_BOTTOM', 'Bottom');
define('_CM_ONLINE', 'Online!');
define('_CM_POSTED', 'Posted'); // Posted date
define('_CM_UPDATED', 'Updated');
define('_CM_THREAD', 'Thread');
define('_CM_POSTER', 'Poster');
define('_CM_JOINED', 'Joined');
define('_CM_POSTS', 'Posts');
define('_CM_FROM', 'From');
define('_CM_COMDELETED', 'Comment(s) deleted.');
define('_CM_COMDELETENG', 'Could not delete comment.');
define('_CM_DELETESELECT', 'Delete all its child comments?');
define('_CM_DELETEONE', 'No, delete only this comment');
define('_CM_DELETEALL', 'Yes, delete all');
define('_CM_THANKSPOST', 'Thanks for posting!');
define('_CM_NOTICE', "The comments are owned by the poster. We aren't responsible for their content.");
define('_CM_COMRULES', 'Comment Rules');
define('_CM_COMAPPROVEALL', 'Comments are always approved');
define('_CM_COMAPPROVEUSER', 'Comments by registered users are always approved');
define('_CM_COMAPPROVEADMIN', 'All comments need to be approved by administrator');
define('_CM_COMANONPOST', 'Allow anonymous post in comments?');
define('_CM_COMNOCOM', 'Disable comments');

?>

==> xoops-2.5.5.tbz: www/xoops/htdocs/language/english/comment.php <==
<?php
// $Id: comment.php 8066 2011-11-06 05:09:33Z beckmi $
// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team
define('_CM_TITLE', 'Title');
define('_CM_MESSAGE', 'Message');
define('_CM_DOSMILEY', 'Enable Smiley Icons');
define('_CM_DOHTML', 'Enable HTML Tags');
define('_CM_DOAUTOWRAP', 'Auto wrap lines');
define('_CM_DOXCODE', 'Enable XOOPS Codes');
define('_CM_REFRESH', 'Refresh');
define('_CM_PENDING', 'Pending');
define('_CM_HIDDEN', 'Hidden');
define('_CM_ACTIVE', 'Active');
define('_CM_STATUS', 'Status');
define('_CM_POSTCOMMENT', 'Publish Comment');
define('_CM_REPLIES', 'Replies');
define('_CM_PARENT', 'Parent');
define('_CM_TOP', 'Top');
define('_CM_BOTTOM', 'Bottom');
define('_CM_ONLINE', 'Online!');
define('_CM_POSTED', 'Published'); // Posted date
define('_CM_UPDATED', 'Updated');
define('_CM_THREAD', 'Thread');
define('_CM_POSTER', 'Author');
define('_CM_JOINED', 'Joined');
define('_CM_POSTS', 'Comments');
define('_CM_FROM', 'From');
define('_CM_COMDELETED', 'Comment(s) deleted.');
define('_CM_COMDELETENG', 'Could not delete comment.');
define('_CM_DELETESELECT', 'Delete all its child comments?');
define('_CM_DELETEONE', 'No, delete only this comment');
define('_CM_DELETEALL', 'Yes, delete all');
define('_CM_THANKSPOST', 'Thanks for your comments!');
define('_CM_NOTICE', "The comments are owned by the author. We aren't responsible for their content.");
define('_CM_COMRULES', 'Comment Rules');
define('_CM_COMAPPROVEALL', 'Comments are always approved');
define('_CM_COMAPPROVEUSER', 'Comments by registered users are always approved');
define('_CM_COMAPPROVEADMIN', 'All comments need to be approved by administrator');
define('_CM_COMANONPOST', 'Allow anonymous comments?');
define('_CM_COMNOCOM', 'Disable comments');

?>
